==> vdr-addon-tvmovie2vdr_0.1.0.orig.tar.gz: vdr-addon-tvmovie2vdr-0.1.0.orig/inc/helperfunc.pl <==
#!/usr/bin/perl

################################################################################
# Constants
################################################################################
sub true           () { 1 };
sub false          () { 0 };
sub CRLF           () { "\r\n" };

################################################################################
# Unpack active-state from timer
################################################################################
sub UnpackActive {
  my($tmstatus) = @_;
  # strip the first 16 bit
  return ($tmstatus & 0xFFFF);
}

################################################################################
# Unpack event_id from timer
################################################################################
sub UnpackEvent_id {
  my($tmstatus) = @_;
  # remove the lower 16 bit by shifting the value 16 bits to the right
  return $tmstatus >> 16;
}

################################################################################
# read timers for given provider
################################################################################
sub gettimers {
	my $prefix = shift;
	undef @oldtimers;
	#Timer holen
	# per SVDRP verbinden
	$SVDRP->command("lstt");
	while($_ = $SVDRP->readoneline) {
		doexit() if $please_exit;
		chomp;
		last if(/^No timers defined/);
		my($id, $temp) = split(/ /, $_, 2);
		my($tmstatus, $vdr_id, $dor, $start, $stop, $prio, $lft, $title, $summary) = split(/\:/, $temp, 9);
		my($active, $event_id);
		$active = UnpackActive($tmstatus);
		$event_id = UnpackEvent_id($tmstatus);
		if ($title =~ /^$prefix/) {
			push @oldtimers, $id;
		}
	}
	return (@oldtimers);
}

################################################################################
# delete timers
################################################################################
sub deltimers {
	my (@timers) = @_;
	foreach $timer (reverse @timers) {
		doexit() if $please_exit;
		my($result) = $SVDRP->SendCMD("delt $timer");
		}
}

################################################################################
# read channels.conf via svdrp into memory
################################################################################
sub getchan {
	undef(@chan);
	$SVDRP->command("lstc");
	while($_ = $SVDRP->readoneline) {
		doexit() if $please_exit;
		chomp;
		my($vdr_id, $temp) = split(/ /, $_, 2);	
		my($name, $frequency, $polarization, $source, $symbolrate, $vpid, $apid,
		  $tpid, $ca, $service_id, $nid, $tid, $rid) = split(/\:/, $temp);

		if ( $source eq 'T' ) { 
			$frequency=substr($frequency, 0, 3);
		}

		$data = $nid>0 ? $tid : $frequency;
		$rfc2838 = "";
		foreach $sender (keys(%chan)) {
			if ($chan{$sender}[0] eq "$source-$nid-$data-$service_id") {
			$rfc2838 = $sender;
			last;
			}	  
		}
		push(@chan, {
			vdr_id       => $vdr_id,
			name         => $name,
			frequency    => $frequency,
			polarization => $polarization,
			source       => $source,
			symbolrate   => $symbolrate,
			vpid         => $vpid,
			apid         => $apid,
			tpid         => $tpid,
			ca           => $ca,
			service_id   => $service_id,
			nid          => $nid,
			tid          => $tid,
			epg_id       => "$source-$nid-$data-$service_id",
			rid          => $rid,
			rfc2838      => $rfc2838
		}); 
	}
	return(@chan);
}

################################################################################
# read channels.conf into memory
################################################################################
sub ReadChannels {
	my $channelsfile = shift;
	# Now open the VDR channel file
	open(CHANNELS, "$channelsfile") || die "cannot open $channelsfile file: $!";
	while(<CHANNELS>) {

		doexit() if $please_exit;
		# Kategorien berspringen
		next if (/^:/);

		chomp;
		my($name, $frequency, $polarization, $source, $symbolrate, $vpid, $apid,
		$tpid, $ca, $service_id, $nid, $tid, $rid) = split(/\:/, $_);

		if ( $source eq 'T' ) { 
			$frequency=substr($frequency, 0, 3);
		}

		$data = $nid>0 ? $tid : $frequency;
		$rfc2838 = "";
		foreach $sender (keys(%chan)) {
			if ($chan{$sender}[0] eq "$source-$nid-$data-$service_id") {
			$rfc2838 = $sender;
			last;
			}	  
		}
		next if $rfc2838 eq "";
		# Channel ins Array aufnehmen
		push(@chan, {
			name         => $name,
			polarization => $polarization,
			source       => $source,
			symbolrate   => $symbolrate,
			vpid         => $vpid,
			apid         => $apid,
			tpid         => $tpid,
			ca           => $ca,
			service_id   => $service_id,
			nid          => $nid,
			tid          => $tid,
			rid          => $rid,
			epg_id		 => "$source-$nid-$data-$service_id",
			rfc2838      => $rfc2838
			}); 
	}
	return(@chan);
}

################################################################################
# get given URL either from web or cache
################################################################################
sub GetContent
{
	my $downloadurl = shift;
	my $cachefile = shift;
	undef $html;
	my $html;

	#print "getting $downloadurl or $cachefile\n";
	use LWP::UserAgent;
	my $ua = new LWP::UserAgent; $ua->agent("Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1)" . $ua->agent);
	$ua->proxy('http', $http_proxy);

	if ($tvicache_files==1 && -s $cachefile ) {
		open(CACHE, "< $cachefile")  || warn "cannot read cachefile file: $!";
		while(<CACHE>) {
			$html .= $_;
		}
		close CACHE;
	} else {
		my $req = new HTTP::Request(GET => $downloadurl);
		my $res = $ua->request($req);
		doexit() if $please_exit;
		$html = $res->content;
		open(CACHE, "> $cachefile")  || warn "cannot write cachefile: $!";
		print CACHE $html;
		close CACHE;
	}

	$loglength = length($html);
	$loggeslength = $loggeslength + $loglength;
	open(LOG, ">> download.log") || die "cannot write to download.log file: $!";
	print LOG "$loggeslength\t\t$loglength\t$downloadurl\n";
	close LOG;


	return $html;
}

sub SIGhandler {    
	my($sig) = @_;
	$please_exit=1;
}

sub doexit {
	print "exiting ... \n";
	$SVDRP->close;
	exit;
}

sub cleanup {
	$yesterday = UnixDate("yesterday", "%Y%m%d");
	$today = UnixDate("today", "%Y%m%d");

	opendir DH, $downloadprefix ;
	@directory = readdir DH ;
	close DH ;
	foreach $file (@directory) {	
		# lter als einen Tag? weg damit.
		if ($file =~ m/$yesterday\./) {
			unlink("$downloadprefix$file");
		}
	}

	opendir DH, $updateprefix ;
	@directory = readdir DH ;
	close DH ;
	foreach $file (@directory) {	
		# lter als einen Tag? weg damit.
		if ($file =~ m/$yesterday\./) {
			unlink("$updateprefix$file");
		}
	}

if ($useupdate) {
	print "lsche Daten von heute ..\n";
	opendir DH, $downloadprefix ;
	@directory = readdir DH ;
	close DH ;
	foreach $file (@directory) {	
		# Daten von heute? download forcieren.
		if ($file =~ m/$today\./) {
			unlink("$downloadprefix$file");
		}
	}
}

}
###############################################################################
#
# package SVDRP
#
package SVDRP;

sub true       () { main::true(); }
sub false      () { main::false(); };
sub CRLF       () { main::CRLF(); };

my($SOCKET, $EPGSOCKET, $query, $connected, $epg);

sub new {
	my $invocant = shift;
	$Dest = shift;
	$Port = shift;
	$verbose = shift;
	$sim = shift;
	my $class = ref($invocant) || $invocant;
	my $self = { };
	bless($self, $class);
	$connected = false;
	$query = false;
	$epg = false;
	return $self;
}

sub myconnect {
	my $this = shift;

	if ($sim == 0) {
		$SOCKET = IO::Socket::INET->new(
			PeerAddr => $Dest, 
			PeerPort => $Port, 
			Proto => 'tcp'
		) || die;

		my $line;
		$line = <$SOCKET>;
		$connected = true;
	}
}

sub close {
	my $this = shift;
	if($connected) {
		command($this, "quit");
		readoneline($this);
		close $SOCKET if $SOCKET;
		$connected = false;
	}
}

sub command {
	my $this = shift;
	my $cmd = join("", @_);

	if ($verbose == 1) {
		print "$cmd\n";
	}

	if ($sim == 1) {
		return;
	}

	if(!$connected ) {
		myconnect($this);
	}
	
	$cmd = $cmd . CRLF;
	if($SOCKET) {
#		use bytes;
		my $result = send($SOCKET, $cmd, 0);
#		no bytes;
		if($result != length($cmd)) {
		} else {
			$query = true;
		}
	}
}

sub readoneline {
	my $this = shift;
	my $line;

	if ($sim == 1) {
		return undef;
	}

	if($connected && $query) {
		$line = <$SOCKET>;
		$line =~ s/\r\n$//;
		if(substr($line, 3, 1) ne "-") {
			$query = 0;
		}
		$line = substr($line, 4, length($line));

		if ($verbose == 1) {
			print "< $line\n";
		}

		return($line);
	} else { 
		return undef; 
	}
}

sub SendCMD {
	my $this = shift;
	my $cmd = join("", @_); 
	my @output;

	if ($sim == 1) {
		print "$cmd \n";
		return (@output);
	}

	command($this, $cmd);
	while($_ = readoneline($this)) {
		push(@output, $_);
	}
  return(@output);
}

return 1;

==> vdr-addon-tvmovie2vdr_0.1.2.orig.tar.gz: vdr-addon-tvmovie2vdr-0.1.2.orig/inc/helperfunc.pl <==
#!/usr/bin/perl

################################################################################
# Constants
################################################################################
sub true           () { 1 };
sub false          () { 0 };
sub CRLF           () { "\r\n" };

################################################################################
# Unpack active-state from timer
################################################################################
sub UnpackActive {
  my($tmstatus) = @_;
  # strip the first 16 bit
  return ($tmstatus & 0xFFFF);
}

################################################################################
# Unpack event_id from timer
################################################################################
sub UnpackEvent_id {
  my($tmstatus) = @_;
  # remove the lower 16 bit by shifting the value 16 bits to the right
  return $tmstatus >> 16;
}

################################################################################
# read timers for given provider
################################################################################
sub gettimers {
	my $prefix = shift;
	undef @oldtimers;
	#Timer holen
	# per SVDRP verbinden
	$SVDRP->command("lstt");
	while($_ = $SVDRP->readoneline) {
		doexit() if $please_exit;
		chomp;
		last if(/^No timers defined/);
		my($id, $temp) = split(/ /, $_, 2);
		my($tmstatus, $vdr_id, $dor, $start, $stop, $prio, $lft, $title, $summary) = split(/\:/, $temp, 9);
		my($active, $event_id);
		$active = UnpackActive($tmstatus);
		$event_id = UnpackEvent_id($tmstatus);
		if ($title =~ /^$prefix/) {
			push @oldtimers, $id;
		}
	}
	return (@oldtimers);
}

################################################################################
# delete timers
################################################################################
sub deltimers {
	my (@timers) = @_;
	foreach $timer (reverse @timers) {
		doexit() if $please_exit;
		my($result) = $SVDRP->SendCMD("delt $timer");
		}
}

################################################################################
# read channels.conf via svdrp into memory
################################################################################
sub getchan {
	undef(@chan);
	$SVDRP->command("lstc");
	while($_ = $SVDRP->readoneline) {
		doexit() if $please_exit;
		chomp;
		my($vdr_id, $temp) = split(/ /, $_, 2);	
		my($name, $frequency, $polarization, $source, $symbolrate, $vpid, $apid,
		  $tpid, $ca, $service_id, $nid, $tid, $rid) = split(/\:/, $temp);

		if ( $source eq 'T' ) { 
			$frequency=substr($frequency, 0, 3);
		}

		$data = $nid>0 ? $tid : $frequency;
		$rfc2838 = "";
		foreach $sender (keys(%chan)) {
			if ($chan{$sender}[0] eq "$source-$nid-$data-$service_id") {
			$rfc2838 = $sender;
			last;
			}	  
		}
		push(@chan, {
			vdr_id       => $vdr_id,
			name         => $name,
			frequency    => $frequency,
			polarization => $polarization,
			source       => $source,
			symbolrate   => $symbolrate,
			vpid         => $vpid,
			apid         => $apid,
			tpid         => $tpid,
			ca           => $ca,
			service_id   => $service_id,
			nid          => $nid,
			tid          => $tid,
			epg_id       => "$source-$nid-$data-$service_id",
			rid          => $rid,
			rfc2838      => $rfc2838
		}); 
	}
	return(@chan);
}

################################################################################
# read channels.conf into memory
################################################################################
sub ReadChannels {
	my $channelsfile = shift;
	# Now open the VDR channel file
	open(CHANNELS, "$channelsfile") || die "cannot open $channelsfile file: $!";
	while(<CHANNELS>) {

		doexit() if $please_exit;
		# Kategorien berspringen
		next if (/^:/);

		chomp;
		my($name, $frequency, $polarization, $source, $symbolrate, $vpid, $apid,
		$tpid, $ca, $service_id, $nid, $tid, $rid) = split(/\:/, $_);

		if ( $source eq 'T' ) { 
			$frequency=substr($frequency, 0, 3);
		}

		$data = $nid>0 ? $tid : $frequency;
		$rfc2838 = "";
		foreach $sender (keys(%chan)) {
			if ($chan{$sender}[0] eq "$source-$nid-$data-$service_id") {
			$rfc2838 = $sender;
			last;
			}	  
		}
		next if $rfc2838 eq "";
		# Channel ins Array aufnehmen
		push(@chan, {
			name         => $name,
			polarization => $polarization,
			source       => $source,
			symbolrate   => $symbolrate,
			vpid         => $vpid,
			apid         => $apid,
			tpid         => $tpid,
			ca           => $ca,
			service_id   => $service_id,
			nid          => $nid,
			tid          => $tid,
			rid          => $rid,
			epg_id		 => "$source-$nid-$data-$service_id",
			rfc2838      => $rfc2838
			}); 
	}
	return(@chan);
}

################################################################################
# get given URL either from web or cache
################################################################################
sub GetContent
{
	my $downloadurl = shift;
	my $cachefile = shift;
	undef $html;
	my $html;
	my $tries = 3;
	my $success = 0;

	#print "getting $downloadurl or $cachefile\n";
	use LWP::UserAgent;
	my $ua = new LWP::UserAgent; $ua->agent("Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1)" . $ua->agent);
	$ua->proxy('http', $http_proxy);

	if ($tvicache_files==1 && -s $cachefile ) {
		open(CACHE, "< $cachefile")  || warn "cannot read cachefile file: $!";
		while(<CACHE>) {
			$html .= $_;
		}
		close CACHE;
	} else {
		while ($tries >= 0 && ! $success) {
			$tries--;
			my $req = new HTTP::Request(GET => $downloadurl);
			my $res = $ua->request($req);
			$success = 1 if $res->is_success;
			doexit() if $please_exit;
			$html = $res->content;
			open(CACHE, "> $cachefile")  || warn "cannot write cachefile: $!";
			print CACHE $html;
			close CACHE;
		}
	}

	$loglength = length($html);
	$loggeslength = $loggeslength + $loglength;
	open(LOG, ">> download.log") || die "cannot write to download.log file: $!";
	print LOG "$loggeslength\t\t$loglength\t$downloadurl\n";
	close LOG;


	return $html;
}

sub SIGhandler {    
	my($sig) = @_;
	$please_exit=1;
}

sub doexit {
	print "exiting ... \n";
	$SVDRP->close;
	exit;
}

sub cleanup {
	$yesterday = UnixDate("yesterday", "%Y%m%d");
	$today = UnixDate("today", "%Y%m%d");

	opendir DH, $downloadprefix ;
	@directory = readdir DH ;
	close DH ;
	foreach $file (@directory) {	
		# lter als einen Tag? weg damit.
		if ($file =~ m/$yesterday/) {
			unlink("$downloadprefix$file");
		}
	}

	opendir DH, $updateprefix ;
	@directory = readdir DH ;
	close DH ;
	foreach $file (@directory) {	
		# lter als einen Tag? weg damit.
		if ($file =~ m/$yesterday/) {
			unlink("$updateprefix$file");
		}
	}

if ($useupdate) {
	print "lsche Daten von heute ..\n";
	opendir DH, $downloadprefix ;
	@directory = readdir DH ;
	close DH ;
	foreach $file (@directory) {	
		# Daten von heute? download forcieren.
		if ($file =~ m/$today/) {
			unlink("$downloadprefix$file");
		}
	}
}

}
###############################################################################
#
# package SVDRP
#
package SVDRP;

sub true       () { main::true(); }
sub false      () { main::false(); };
sub CRLF       () { main::CRLF(); };

my($SOCKET, $EPGSOCKET, $query, $connected, $epg);

sub new {
	my $invocant = shift;
	$Dest = shift;
	$Port = shift;
	$verbose = shift;
	$sim = shift;
	my $class = ref($invocant) || $invocant;
	my $self = { };
	bless($self, $class);
	$connected = false;
	$query = false;
	$epg = false;
	return $self;
}

sub myconnect {
	my $this = shift;

	if ($sim == 0) {
		$SOCKET = IO::Socket::INET->new(
			PeerAddr => $Dest, 
			PeerPort => $Port, 
			Proto => 'tcp'
		) || die;

		my $line;
		$line = <$SOCKET>;
		$connected = true;
	}
}

sub close {
	my $this = shift;
	if($connected) {
		command($this, "quit");
		readoneline($this);
		close $SOCKET if $SOCKET;
		$connected = false;
	}
}

sub command {
	my $this = shift;
	my $cmd = join("", @_);

	if ($verbose == 1) {
		print "$cmd\n";
	}

	if ($sim == 1) {
		return;
	}

	if(!$connected ) {
		myconnect($this);
	}
	
	$cmd = $cmd . CRLF;
	if($SOCKET) {
#		use bytes;
		my $result = send($SOCKET, $cmd, 0);
#		no bytes;
		if($result != length($cmd)) {
		} else {
			$query = true;
		}
	}
}

sub readoneline {
	my $this = shift;
	my $line;

	if ($sim == 1) {
		return undef;
	}

	if($connected && $query) {
		$line = <$SOCKET>;
		$line =~ s/\r\n$//;
		if(substr($line, 3, 1) ne "-") {
			$query = 0;
		}
		$line = substr($line, 4, length($line));

		if ($verbose == 1) {
			print "< $line\n";
		}

		return($line);
	} else { 
		return undef; 
	}
}

sub SendCMD {
	my $this = shift;
	my $cmd = join("", @_); 
	my @output;

	if ($sim == 1) {
		print "$cmd \n";
		return (@output);
	}

	command($this, $cmd);
	while($_ = readoneline($this)) {
		push(@output, $_);
	}
  return(@output);
}

return 1;
